==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SzablonWydrukuTresc.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SzablonWydrukuTresc extends GenericDPSObject {
    /**
     * SZABLON_WYDRUKU_TRESC.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SZABLON_WYDRUKU_TRESC.TRESC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String tresc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SZABLON_WYDRUKU_TRESC.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SZABLON_WYDRUKU_TRESC.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SZABLON_WYDRUKU_TRESC.TRESC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTresc() {
        return tresc;
    }

    /**
     * SZABLON_WYDRUKU_TRESC.TRESC
     *
     * @param tresc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTresc(String tresc) {
        this.tresc = tresc == null ? null : tresc.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SzablonWydrukuTresc other = (SzablonWydrukuTresc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTresc() == null ? other.getTresc() == null : this.getTresc().equals(other.getTresc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTresc() == null) ? 0 : getTresc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", tresc=").append(tresc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SzablonWydrukuTresc.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SzablonWydrukuTresc extends GenericDPSObject {
    /**
     * SZABLON_WYDRUKU_TRESC.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SZABLON_WYDRUKU_TRESC.TRESC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String tresc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SZABLON_WYDRUKU_TRESC.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SZABLON_WYDRUKU_TRESC.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SZABLON_WYDRUKU_TRESC.TRESC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTresc() {
        return tresc;
    }

    /**
     * SZABLON_WYDRUKU_TRESC.TRESC
     *
     * @param tresc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTresc(String tresc) {
        this.tresc = tresc == null ? null : tresc.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SzablonWydrukuTresc other = (SzablonWydrukuTresc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTresc() == null ? other.getTresc() == null : this.getTresc().equals(other.getTresc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTresc() == null) ? 0 : getTresc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", tresc=").append(tresc);
        sb.append("]");
        return sb.toString();
    }
}
